# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-YAML
Version:	1.31
Release:	1.%{__distinit}%{__distvers}
Summary:	YAML Ain't Markup Language (tm)
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/YAML
Source0:	https://cpan.metacpan.org/modules/by-module/YAML/YAML-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.42
# Module Runtime
BuildRequires:	perl(B)
BuildRequires:	perl(B::Deparse)
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(overload)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
%if 0%{!?perl_bootstrap:1}
# Test Suite (note: Test::YAML requires YAML)
BuildRequires:	perl(Config)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Encode)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(IO::Pipe)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::Deep)
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(Test::YAML) >= 1.05
BuildRequires:	perl(utf8)
# Author Tests
BuildRequires:	perl(Test::Pod) >= 1.41
%endif
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(B::Deparse)
Requires:	perl(Carp)

# Filter private provides:
# perl(yaml_mapping) perl(yaml_scalar) perl(yaml_sequence)
%global __provides_exclude ^perl\\(yaml_

%description
If you need to use YAML with Perl, it is likely that you will have a look at
this module (YAML.pm) first. There are several YAML modules in Perl and they
all support the simple Load() and Dump() API. Since this one has the obvious
name "YAML", it may seem obvious to pick this one.

The author of this module humbly asks you to choose another. YAML.pm was the
very first YAML implementation in the world, released in 2001. It was
originally made as a prototype, over 2 years before the YAML 1.0 spec was
published. Although it may work for your needs, it has numerous bugs and is
barely maintained.

Please consider using these first:
 * YAML::PP - Pure Perl, full featured, well maintained
 * YAML::PP::LibYAML - A libyaml Perl binding like YAML::XS but with the
   YAML::PP API

%prep
%setup -q -n YAML-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
%if 0%{!?perl_bootstrap:1}
make test AUTHOR_TESTING=1
%endif

%files
%license LICENSE
%doc Changes CONTRIBUTING README
%dir %{perl_vendorlib}/YAML/
%dir %{perl_vendorlib}/YAML/Dumper/
%dir %{perl_vendorlib}/YAML/Loader/
%doc %{perl_vendorlib}/YAML.pod
%doc %{perl_vendorlib}/YAML/Any.pod
%doc %{perl_vendorlib}/YAML/Dumper.pod
%doc %{perl_vendorlib}/YAML/Dumper/Base.pod
%doc %{perl_vendorlib}/YAML/Error.pod
%doc %{perl_vendorlib}/YAML/Loader.pod
%doc %{perl_vendorlib}/YAML/Loader/Base.pod
%doc %{perl_vendorlib}/YAML/Marshall.pod
%doc %{perl_vendorlib}/YAML/Node.pod
%doc %{perl_vendorlib}/YAML/Tag.pod
%doc %{perl_vendorlib}/YAML/Types.pod
%{perl_vendorlib}/YAML.pm
%{perl_vendorlib}/YAML/Any.pm
%{perl_vendorlib}/YAML/Dumper.pm
%{perl_vendorlib}/YAML/Dumper/Base.pm
%{perl_vendorlib}/YAML/Error.pm
%{perl_vendorlib}/YAML/Loader.pm
%{perl_vendorlib}/YAML/Loader/Base.pm
%{perl_vendorlib}/YAML/Marshall.pm
%{perl_vendorlib}/YAML/Mo.pm
%{perl_vendorlib}/YAML/Node.pm
%{perl_vendorlib}/YAML/Tag.pm
%{perl_vendorlib}/YAML/Types.pm
%{_mandir}/man3/YAML.3*
%{_mandir}/man3/YAML::Any.3*
%{_mandir}/man3/YAML::Dumper.3*
%{_mandir}/man3/YAML::Dumper::Base.3*
%{_mandir}/man3/YAML::Error.3*
%{_mandir}/man3/YAML::Loader.3*
%{_mandir}/man3/YAML::Loader::Base.3*
%{_mandir}/man3/YAML::Marshall.3*
%{_mandir}/man3/YAML::Node.3*
%{_mandir}/man3/YAML::Tag.3*
%{_mandir}/man3/YAML::Types.3*

%changelog
* Thu Dec 28 2023 Paul Howarth <paul@city-fan.org> - 1.31-1
- Update to 1.31 (rhbz#2255994)
  - Update docs to recommend YAML::PP
- Package description updated as per upstream documentation

* Fri Mar  3 2023 Paul Howarth <paul@city-fan.org> - 1.30-15
- Use SPDX-format license tag
- Use %%license unconditionally
- Drop support for ancient distributions with rpm < 4.9

* Tue Jan 28 2020 Paul Howarth <paul@city-fan.org> - 1.30-1
- Update to 1.30
  - Breaking Change: Set $YAML::LoadBlessed default to false to make it more
    secure

* Sat May 11 2019 Paul Howarth <paul@city-fan.org> - 1.29-1
- Update to 1.29
  - Fix regex for alias to match the one for anchors (GH#214)

* Sun Apr 28 2019 Paul Howarth <paul@city-fan.org> - 1.28-1
- Update to 1.28
  - Security fix: only enable loading globs when $LoadCode is set (GH#213)

* Sat Nov  3 2018 Paul Howarth <paul@city-fan.org> - 1.27-1
- Update to 1.27
  - Remove a warning about uninitialized value for perl ≤ 5.10
- Switch upstream from search.cpan.org to metacpan.org

* Sun May 20 2018 Paul Howarth <paul@city-fan.org> - 1.26-1
- Update to 1.26
  - Fix bug introduced in 1.25 - loading of quoted string with colon as
    sequence element (GH#208)
  - Support zero indented block sequences (GH#207)

* Sat May 12 2018 Paul Howarth <paul@city-fan.org> - 1.25-1
- Update to 1.25
  - Support trailing comments (GH#189, GH#190, GH#191)
  - Remove unused code (GH#192)
  - Use Test::Deep to actually test correctly for class names (GH#193)
  - Fix loading of mapping key that starts with '= ' (GH#194)
  - Fix loading strings with multiple spaces (GH#172)
  - Allow more characters in anchor name (GH#196)
  - Add $YAML::LoadBlessed for disabling loading objects (GH#197)
  - Disable test with long string under certain conditions (GH#201)
  - Quote scalar if it equals '=' (GH#202)
  - Multiple regexp roundtrip does not grow (GH#203)
  - Add support for compact nested block sequences (GH#204)
  - Support reverse order of block scalar indicators (GH#205)
  - Support nested mappings in sequences (GH#206)
  - Fix parsing of quoted strings (GH#188)

* Tue Oct 31 2017 Paul Howarth <paul@city-fan.org> - 1.24-1
- Update to 1.24
  - Fix $LoadCode (GH#180, GH#181, GH#182)
- This release by TINITA → update source URL
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with ExtUtils::MakeMaker < 6.42
  - Drop workaround for building with Test::More < 0.88
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Mon Feb 20 2017 Paul Howarth <paul@city-fan.org> - 1.23-1
- Update to 1.23
  - Fix $YAML::Numify (empty values were converted to 0)

* Wed Feb 15 2017 Paul Howarth <paul@city-fan.org> - 1.22-1
- Update to 1.22
  - Add $YAML::Numify
- Update patch for building with Test::More < 0.88

* Sat Dec 24 2016 Paul Howarth <paul@city-fan.org> - 1.21-1
- Update to 1.21
  - Declare variables with our() to avoid warnings (GH#109, GH#171)
  - Empty mapping value at the end resolves to null (was becoming empty string)
    (GH#131, GH#170)
  - Output key in warning when duplicate key was found (GH#119, GH#169)
  - Allow reading and writing to IO::Handle (GH#157, GH#168)

* Sat Dec  3 2016 Paul Howarth <paul@city-fan.org> - 1.20-1
- Update to 1.20
 - Allow quoted map keys in arrays (GH#146)
 - B::Deparse is loaded at runtime now
 - New feature $YAML::Preserve (GH#9)
- This release by INGY → update source URL
- Update patch for building with Test::More < 0.88

* Sat Nov 19 2016 Paul Howarth <paul@city-fan.org> - 1.19-1
- Update to 1.19
  - Add pod link to YAML::Shell (GH#164)
  - Fix infinite loop for aliases without a name (GH#151)
  - Improve error messages (GH#142, GH#162)
  - Trailing spaces after inline seq/map work now (GH#163)
  - Add test case for trailing comments (GH#154)

* Tue Jul 26 2016 Paul Howarth <paul@city-fan.org> - 1.18-2
- Fix FTBFS when perl is not in the minimal buildroot

* Sat Jul  9 2016 Paul Howarth <paul@city-fan.org> - 1.18-1
- Update to 1.18
  - List Test::More as a prereq (GH#161)

* Wed Jul  6 2016 Paul Howarth <paul@city-fan.org> - 1.17-1
- Update to 1.17
  - Use Mo 0.40
- This release by TINITA → update source URL

* Sun Jul  3 2016 Paul Howarth <paul@city-fan.org> - 1.16-1
- Update to 1.16
  - Drop inconsistent $VERSION from YAML::Mo (GH#158)
- BR: perl-generators where available
- Simplify find command using -delete
- Pod test is now an author test rather than a release test

* Wed Jul  1 2015 Paul Howarth <paul@city-fan.org> - 1.15-4
- Perl 5.22 re-rebuild of bootstrapped packages

* Tue Jun 16 2015 Paul Howarth <paul@city-fan.org> - 1.15-2
- Perl 5.22 bootstrap

* Mon Apr 20 2015 Paul Howarth <paul@city-fan.org> - 1.15-1
- Update to 1.15
  - Don't require newlines at end of YAML (GH#149)
- Update patch for building with Test::More < 0.88

* Mon Jan 26 2015 Paul Howarth <paul@city-fan.org> - 1.14-1
- Update to 1.14
  - Add support for QuoteNumericStrings global setting (PR/145)

* Sun Oct 12 2014 Paul Howarth <paul@city-fan.org> - 1.13-1
- Update to 1.13
  - Disable some warnings in YAML::Any (PR/140)

* Wed Sep 24 2014 Paul Howarth <paul@city-fan.org> - 1.12-1
- Update to 1.12
  - Fix parsing of unquoted strings (CPAN RT#97870)
- Classify buildreqs by usage

* Tue Sep  2 2014 Paul Howarth <paul@city-fan.org> - 1.11-1
- Update to 1.11
  - Apply PR/139:
    -  Remove die() that can't be called (regex always matches)

* Fri Aug 29 2014 Paul Howarth <paul@city-fan.org> - 1.10-2
- Perl 5.20 rebuild

* Fri Aug 29 2014 Paul Howarth <paul@city-fan.org> - 1.10-1
- Update to 1.10
  - Apply PR/138:
    - Report an error message mentioning indentation when choking on non-space
      indentation
    - die() should be called as a method of $self

* Tue Aug 26 2014 Paul Howarth <paul@city-fan.org> - 1.09-1
- Update to 1.09
  - Add t/000-compile-modules.t
  - Eliminate File::Basename from test/
  - Eliminate spurious trailing whitespace
  - Meta 0.0.2
  - Change testdir to t
  - Add doc examples for YAML::Any (PR/8)
  - Dep on Test::YAML 1.05
  - Replace tabs with spaces
- Update patch for building with Test::More < 0.88

* Sun Aug 17 2014 Paul Howarth <paul@city-fan.org> - 1.01-2
- Don't run the test suite when bootstrapping

* Fri Aug  8 2014 Paul Howarth <paul@city-fan.org> - 1.01-1
- Update to 1.01
  - Depend on patched Test::YAML

* Thu Aug  7 2014 Paul Howarth <paul@city-fan.org> - 1.00-1
- Update to 1.00
  - Switch to external Test::Base
  - Fix bad encoding in Pod
- Test::YAML is now unbundled
- Bundle a recent ExtUtils::MakeMaker for building on old distributions
  (https://github.com/ingydotnet/yaml-pm/issues/32)

* Thu Jul 31 2014 Paul Howarth <paul@city-fan.org> - 0.98-1
- Update to 0.98
  - Fix indexing of YAML::Any
  - Change IRC to irc.perl.org#yaml
- Use %%license where possible
- Drop workaround for #1115971

* Thu Jul 24 2014 Paul Howarth <paul@city-fan.org> - 0.97-2
- Inject VERSION into each module (#1115971)

* Thu Jul 17 2014 Paul Howarth <paul@city-fan.org> - 0.97-1
- Update to 0.97
  - Move remaining docs to Swim
- Upstream reinstated all those pod files and manpages again

* Mon Jul 14 2014 Paul Howarth <paul@city-fan.org> - 0.96-1
- Update to 0.96
  - Fix Metadata and add Contributing file
  - Change Kwim to Swim
- Upstream dropped all those pod files and manpages again

* Mon Jun 23 2014 Paul Howarth <paul@city-fan.org> - 0.95-1
- Update to 0.95
  - Fix dumping blessed globs

* Sun Jun 15 2014 Paul Howarth <paul@city-fan.org> - 0.94-1
- Update to 0.94
  - Switch to Zilla::Dist
  - Add badges to doc
  - Fix regression introduced with earlier fix for complex regular
    subexpression recursion limit (GH#18)
  - Fix reference to non-existent sub Carp::Croak (GH#19)
- Add patch to support building with Test::More < 0.88
- Enumerate all files so we can mark POD files as %%doc

* Thu May 29 2014 Paul Howarth <paul@city-fan.org> - 0.92-1
- Update to 0.92
  - Metadata fixes (https://github.com/ingydotnet/yaml-pm/pull/23)

* Wed May 28 2014 Paul Howarth <paul@city-fan.org> - 0.91-1
- Update to 0.91
  - Force escaping of single '-'
    (https://github.com/ingydotnet/yaml-pm/pull/22)

* Tue Feb 11 2014 Paul Howarth <paul@city-fan.org> - 0.90-1
- Update to 0.90
  - Revert Mo from 0.38 to 0.31 following a report of it breaking cpan client

* Sun Feb  9 2014 Paul Howarth <paul@city-fan.org> - 0.89-1
- Update to 0.89
  - Fixed tests to work under parallel testing
  - Switched to dzil release process
- Drop old perl patches and don't try to build with perl < 5.8.8 as
  t/load-tests.t runs out of memory
- Drop %%defattr, redundant since rpm 4.4

* Tue Dec  3 2013 Paul Howarth <paul@city-fan.org> - 0.88-1
- Update to 0.88
  - Fixed YAML loading on perl 5.8 (broken in YAML 0.85) by removing
    5.10-specific regex construct
- Update old-perl patch, since the upstream fix doesn't actually work

* Mon Dec  2 2013 Paul Howarth <paul@city-fan.org> - 0.87-1
- Update to 0.87
  - Use latest Test::Builder (CPAN RT#90847)

* Tue Nov 26 2013 Paul Howarth <paul@city-fan.org> - 0.86-1
- Update to 0.86
  - Revert YAML::Mo (CPAN RT#90817)

* Tue Nov 26 2013 Paul Howarth <paul@city-fan.org> - 0.85-1
- Update to 0.85
  - Synopsis in YAML::Dumper didn't work as expected (CPAN RT#19838)
  - Address complex regular subexpression recursion limit (CPAN RT#90593)
  - Upgrade to latest Mo
- This release by INGY -> update source URL
- Add patch to support use with Perl < 5.10

* Fri Jul 13 2012 Paul Howarth <paul@city-fan.org> - 0.84-1
- Update to 0.84
  - Resolve distribution error that caused .git to be shipped in the tarball

* Fri Jul 13 2012 Paul Howarth <paul@city-fan.org> - 0.83-1
- Update to 0.83
  - Only call stat() and tell() on a filehandle if fileno existed
  - Explicit tied() call on globs to avoid a 5.16 deprecation warning

* Thu Jul 12 2012 Paul Howarth <paul@city-fan.org> - 0.82-1
- Update to 0.82
  - Test scalar @array rather than deprecated defined @array (CPAN RT#74226)
- Drop upstreamed patch for CPAN RT#74226

* Tue Jun 12 2012 Paul Howarth <paul@city-fan.org> - 0.81-4
- Fix deprecation warning in YAML::Any with Perl 5.15.7 onwards (CPAN RT#74226)

* Thu Apr 19 2012 Paul Howarth <paul@city-fan.org> - 0.81-1
- Update to 0.81
  - Test fixes for 5.16 (CPAN RT#74826)
  - YAML::Mo uses Safe Mo (CPAN RT#76664)
- BR:/R: perl(Carp) and perl(Data::Dumper)
- Add patch to fix broken upstream fix for old B::Deparse versions
  (CPAN RT#74826, CPAN RT#74687, CPAN RT#73702)

* Tue Mar 20 2012 Paul Howarth <paul@city-fan.org> - 0.80-2
- BR: perl(constant) and perl(Exporter)
- Package the LICENSE file
- Don't need to remove empty directories from buildroot
- Drop support for distributions prior to FC-3:
  - Always run the whole test suite
  - Don't patch away the Perl 5.8.1 requirement
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Sat Feb 11 2012 Paul Howarth <paul@city-fan.org> - 0.80-1
- Update to 0.80
  - Work around Perl RT#35857 on old distributions (CPAN RT#73702)
  - Make YAML::Node subclass YAML::Mo::Object as well as Exporter
- Drop upstreamed patch for Perl RT#35857 workaround

* Thu Feb  9 2012 Paul Howarth <paul@city-fan.org> - 0.79-1
- Update to 0.79
  - Mo::xxx was causing problems on newer perls and has been removed for now
- Drop UTF8 patch, no longer needed

* Tue Jan  3 2012 Paul Howarth <paul@city-fan.org> - 0.78-1
- Update to 0.78
  - Apply patch from ANDK++ to deal with B::Deparse changes
- Upstream no longer shipping POD for YAML::Mo
- Add patch to work around Perl RT#35857 on old distributions

* Thu Sep 29 2011 Paul Howarth <paul@city-fan.org> - 0.77-1
- Update to 0.77
  - Add $VERSION back to all modules

* Wed Sep 28 2011 Paul Howarth <paul@city-fan.org> - 0.76-1
- Update to 0.76
  - Removed YAML::import per mst

* Tue Sep 27 2011 Paul Howarth <paul@city-fan.org> - 0.75-1
- Update to 0.75
  - Switch to Mo for OO (YAML::Mo)
  - use_test_base in Makefile.PL
- Drop bundled Test-Simple as upstream has included needed bits again
- Drop BR: perl(Test::Base) as upstream has bundled it again
- Drop manpage for YAML::Base, no longer included

* Mon Sep 26 2011 Paul Howarth <paul@city-fan.org> - 0.74-1
- Update to 0.74
  - Switch to Module::Package
  - Removed extra $VERSION lines from submodules
- Use a patch rather than scripted iconv to fix README encoding
- Don't run release tests as upstream didn't ship them
- Drop release test buildreqs perl(Test::CPAN::Meta),
  perl(Test::MinimumVersion) and perl(Test::Pod)
- BR: perl(Test::Base)
- Package manpage for YAML::Mo
- Filter private provides perl(yaml_mapping), perl(yaml_scalar) and
  perl(yaml_sequence)
- YAML used to bundle a recent copy of bits of Test-Simple that it needed
  but no longer does so, so do it ourselves for support of old releases

* Thu Jun 30 2011 Paul Howarth <paul@city-fan.org> - 0.73-2
- Rebuild for perl 5.14.1 in Rawhide
- Add support for perl_bootstrap macro
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Apr 19 2011 Paul Howarth <paul@city-fan.org> - 0.73-1
- Update to 0.73
  - Apply ANDK's patch for 5.14.0 (CPAN RT#62258)
- This release by INGY -> update source URL
- Use %%{_fixperms} macro instead of our own chmod incantation
- Nobody else likes macros for commands
- Update patch for perl 5.8.0 support

* Mon Sep  6 2010 Paul Howarth <paul@city-fan.org> - 0.72-1
- Update to 0.72
  - Upgrade to Module::Install 1.00
  - Upgraded author tests via new ADAMK release automation
  - Normalise Ingy's name to ASCII in Makefile.PL so that we don't have
    Unicode in our own META.yml
- Explicitly run author tests

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 0.71-3
- Rebuild for perl 5.12.1 in Rawhide

* Wed May 12 2010 Paul Howarth <paul@city-fan.org> - 0.71-2
- Fix dist tag for RHEL-6 Beta

* Mon Jan  4 2010 Paul Howarth <paul@city-fan.org> - 0.71-1
- Update to 0.71 (use UTF-8 encoding in LoadFile/DumpFile: CPAN RT#25434)
- Add patch to support build on perl 5.8.0 (no longer supported upstream)
- Dist tag for Rawhide no longer needs special-casing

* Tue Aug 11 2009 Paul Howarth <paul@city-fan.org> - 0.70-1
- Update to 0.70
- New upstream maintainer -> new source URL
- Enable AUTOMATED_TESTING
- BR: perl(Test::CPAN::Meta), perl(Test::MinimumVersion), perl(Test::Pod)
- Switch off verbose test mode

* Thu Dec  4 2008 Paul Howarth <paul@city-fan.org> - 0.68-1
- Update to 0.68

* Tue Dec  2 2008 Paul Howarth <paul@city-fan.org> - 0.67-1
- Update to 0.67
- ysh moved out to separate distribution, YAML::Shell
- COMPATIBILITY file no longer included in upstream distribution
- More explicit %%files list
- Recode README as UTF8

* Thu Oct 16 2008 Paul Howarth <paul@city-fan.org> - 0.66-2
- Tweak dist tag macros to work on current Rawhide with three-part releasenum
- Apply patch to remove failing test on perl 5.8.0 to allow builds on RHL9 &
  RHEL3
- Run tests in verbose mode

* Fri Sep 28 2007 Paul Howarth <paul@city-fan.org> - 0.66-1
- Update to 0.66
- Clarify license as GPL version 1 or later, or Artistic (same as perl)

* Fri Jun 22 2007 Paul Howarth <paul@city-fan.org> - 0.65-1
- Update to 0.65

* Mon Mar 26 2007 Paul Howarth <paul@city-fan.org> - 0.62-4
- Import from Fedora Extras
- Use search.cpan.org download URL
- Macro-ize commands where possible, use full command paths otherwise
- Include dist tag macros
- Cosmetic spec file changes
- BuildRequire perl >= 3:5.8.3 (regex test fails on 5.8.0)

* Tue Mar 13 2007 Steven Pritchard <steve@kspei.com> - 0.62-3
- Use fixperms macro instead of our own chmod incantation
- Drop Test::Base build dependency to avoid a BR loop
- BR ExtUtils::MakeMaker

* Sat Sep 16 2006 Steven Pritchard <steve@kspei.com> - 0.62-2
- Fix find option order

* Fri Jul 07 2006 Steven Pritchard <steve@kspei.com> - 0.62-1
- Update to 0.62
- Removed Test::YAML (bug #197539)

* Mon Jul 03 2006 Steven Pritchard <steve@kspei.com> - 0.61-1
- Update to 0.61

* Sat May 20 2006 Steven Pritchard <steve@kspei.com> - 0.58-3
- Rebuild

* Tue May 09 2006 Steven Pritchard <steve@kspei.com> - 0.58-2
- Drop testmore patch
- Catch Test::YAML module and man page in file list

* Thu May 04 2006 Steven Pritchard <steve@kspei.com> - 0.58-1
- Update to 0.58
- Small spec cleanups

* Thu Apr 14 2005 Ville Skyttä <ville.skytta at iki.fi> - 0.39-2
- 0.39

* Wed Apr  6 2005 Michael Schwendt <mschwendt[AT]users.sf.net>
- Rebuilt

* Sat May 15 2004 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0:0.35-0.fdr.5
- Avoid creation of the perllocal.pod file (make pure_install)

* Sun Apr 25 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.35-0.fdr.4
- Require perl(:MODULE_COMPAT_*)
- Cosmetic tweaks (bug 1383)

* Sun Mar 14 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.35-0.fdr.3
- Reduce directory ownership bloat

* Tue Nov 18 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:0.35-0.fdr.2
- Use INSTALLARCHLIB workaround in %%install

* Wed Sep  3 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:0.35-0.fdr.1
- First build
